alter table store
    add daily_pay_store_association tinyint default 0 null comment '是否关联每日付门店 0:不关联 1:关联 默认 0';

alter table store
    add daily_pay_mch_id varchar(150) null comment '每日付门店商户编号';

alter table store
    add daily_pay_store_id varchar(150) null comment '每日付门店编号';

alter table store
    add daily_pay_store_name varchar(150) null comment '每日付门店名称';

create unique index idx_daily_pay_store_id
    on store (daily_pay_store_id)
    comment '每日付门店编号(ID)';




alter table card
    add term_card_type tinyint default 0 null comment '期限卡类型 0:普通会员卡 1:月付卡';

alter table card
    add term_card_reservation_limit_type tinyint null comment '期限卡每月可预约次数上限类型 0:自然月限制(每月的1号到月底(3月1号-3月31号))，1:开卡日期限制（开卡日期的当月到下月的开卡日期(3月15号-4月15号)）';

alter table card
    add term_card_reservation_limit int null comment '期限卡每月可约次数上限取值';

alter table card
    add daily_pay_product_id varchar(150) null comment '(月付卡)安心付商品ID';

alter table card
    add daily_pay_product_name varchar(200) null comment '(月付卡)安心付商品名称';

alter table card
    add daily_pay_product_price decimal(10, 2) null comment '(月付卡)安心付商品价格(元)';

alter table card
    add daily_pay_total_price decimal(10, 2) null comment '(月付卡)安心付商品总售价(元)';

alter table card
    add daily_pay_total_original_price decimal(10, 2) null comment '(月付卡)安心付商品总原价(元)';

alter table card
    add daily_pay_product_periods tinyint null comment '(月付卡)安心付商品分期数';

alter table card
    add daily_pay_product_buy_code_url text null comment '(月付卡)安心付商品购买码链接';

alter table card
    add daily_pay_product_cover text null comment '(期限卡)安心付商品封面';

alter table card
    add daily_pay_product_is_open_store tinyint null comment '(安心付)是否开放门店 0:否；1:是';

alter table card
    add daily_pay_product_open_store_count int null comment '(安心付)开放门店数量';



-- 表: 每日付关联会员卡关联门店信息
CREATE TABLE IF NOT EXISTS `daily_pay_card_store` (
  `id` bigint(20) NOT NULL AUTO_INCREMENT COMMENT '主键',
  `card_uuid` bigint(20) NOT NULL COMMENT 'card.uuid',
  `store_uuid` bigint(20) NOT NULL COMMENT 'store.uuid',
  `create_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
  `update_time` datetime NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
  PRIMARY KEY (`id`),
  UNIQUE KEY `uk_member_card_store` (`card_uuid`, `store_uuid`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COMMENT='每日付关联会员卡关联门店信息';

-- idx: store_uuid
CREATE INDEX `idx_store_uuid` ON `daily_pay_card_store` (`store_uuid`);




alter table store_card
    add daily_pay_card_status tinyint default 0 null comment '(月付卡)安心付会员卡上架状态 0: 下架 1: 上架 默认:0  card.term_card_type=1 此值才有效';


alter table store_card
    add term_card_reservation_limit_type tinyint null comment '(优先级高于card.term_card_reservation_limit_type)期限卡每月可预约次数上限类型 0:自然月限制(每月的1号到月底(3月1号-3月31号))，1:开卡日期限制（开卡日期的当月到下月的开卡日期(3月15号-4月15号)）';

alter table store_card
    add term_card_reservation_limit int null comment '(优先级高于card.term_card_reservation_limit)期限卡每月可约次数上限取值';


alter table user
    add monthly_pay_card_module_status tinyint default 0 null comment '用户是否已经进入了过月付卡模块 0:未进入月付卡模块 1:已经进入月付卡模块 默认:0';


CREATE TABLE `mini_program_dictionary`
(
    `uuid`        BIGINT    NOT NULL COMMENT '主键，雪花算法ID',
    `type`        TINYINT   NOT NULL DEFAULT 0 COMMENT '类型：0-月付费卡订购须知',
    `content`     TEXT      NOT NULL COMMENT '内容',
    `create_time` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `update_time` DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`uuid`)
) ENGINE = InnoDB
  DEFAULT CHARSET = utf8mb4 COMMENT ='小程序字典数据表';

CREATE INDEX idx_type ON mini_program_dictionary(type);


alter table user_card
    modify reference_type tinyint(1) null comment '推荐人类型：1-员工；2-会员；3-陌生人; 4-无(月付卡)';


alter table card
    add daily_pay_product_no varchar(150) null comment '(月付卡)安心付商品编号' after daily_pay_product_id;

alter table user_card
    add daily_pay_order_id varchar(150) null comment '每日付订单ID:subscriptionNo';

alter table user_card
    add daily_pay_order_period int null comment '每日付期数';

create index idx_daily_pay_order_id
    on user_card (daily_pay_order_id);